destinations property
Required. Array of destinations, which determines the columns of the response matrix.
Implementation
@$pb.TagNumber(2)
$core.List<RouteMatrixDestination> get destinations => $_getList(1);
Required. Array of destinations, which determines the columns of the response matrix.
@$pb.TagNumber(2)
$core.List<RouteMatrixDestination> get destinations => $_getList(1);