routingPreference property
Optional. Specifies how to compute the route. The server attempts to use
the selected routing preference to compute the route. If the routing
preference results in an error or an extra long latency, an error is
returned. You can specify this option only when the travel_mode is
DRIVE or TWO_WHEELER, otherwise the request fails.
Implementation
@$pb.TagNumber(4)
$31.RoutingPreference get routingPreference => $_getN(3);
Implementation
@$pb.TagNumber(4)
set routingPreference($31.RoutingPreference v) {
setField(4, v);
}