reason property

  1. @TagNumber.new(2)
FallbackReason get reason

The reason why fallback response was used instead of the original response. This field is only populated when the fallback mode is triggered and the fallback response is returned.

Implementation

@$pb.TagNumber(2)
FallbackReason get reason => $_getN(1);
  1. @TagNumber.new(2)
set reason (FallbackReason v)

Implementation

@$pb.TagNumber(2)
set reason(FallbackReason v) {
  setField(2, v);
}