intermediateWaypointRequestIndex property

  1. @TagNumber.new(2)
int get intermediateWaypointRequestIndex

The index of the corresponding intermediate waypoint in the request. Only populated if the corresponding waypoint is an intermediate waypoint.

Implementation

@$pb.TagNumber(2)
$core.int get intermediateWaypointRequestIndex => $_getIZ(1);
  1. @TagNumber.new(2)
set intermediateWaypointRequestIndex (int v)

Implementation

@$pb.TagNumber(2)
set intermediateWaypointRequestIndex($core.int v) {
  $_setSignedInt32(1, v);
}