partialMatch property

  1. @TagNumber.new(4)
bool get partialMatch

Indicates that the geocoder did not return an exact match for the original request, though it was able to match part of the requested address. You may wish to examine the original request for misspellings and/or an incomplete address.

Implementation

@$pb.TagNumber(4)
$core.bool get partialMatch => $_getBF(3);
  1. @TagNumber.new(4)
set partialMatch (bool v)

Implementation

@$pb.TagNumber(4)
set partialMatch($core.bool v) {
  $_setBool(3, v);
}