duration property

  1. @TagNumber.new(3)
Duration get duration

The length of time needed to navigate the route. If you set the routing_preference to TRAFFIC_UNAWARE, then this value is the same as static_duration. If you set the routing_preference to either TRAFFIC_AWARE or TRAFFIC_AWARE_OPTIMAL, then this value is calculated taking traffic conditions into account.

Implementation

@$pb.TagNumber(3)
$10.Duration get duration => $_getN(2);
  1. @TagNumber.new(3)
set duration (Duration v)

Implementation

@$pb.TagNumber(3)
set duration($10.Duration v) {
  setField(3, v);
}