routeLabels property

  1. @TagNumber.new(13)
List<RouteLabel> get routeLabels

Labels for the Route that are useful to identify specific properties of the route to compare against others.

Implementation

@$pb.TagNumber(13)
$core.List<$20.RouteLabel> get routeLabels => $_getList(12);