routeToken property

  1. @TagNumber.new(12)
String get routeToken

An opaque token that can be passed to Navigation SDK to reconstruct the route during navigation, and, in the event of rerouting, honor the original intention when the route was created. Treat this token as an opaque blob. Don't compare its value across requests as its value may change even if the service returns the exact same route.

NOTE: Route.route_token is only available for requests that have set ComputeRoutesRequest.routing_preference to TRAFFIC_AWARE or TRAFFIC_AWARE_OPTIMAL. Route.route_token is not supported for requests that have Via waypoints.

Implementation

@$pb.TagNumber(12)
$core.String get routeToken => $_getSZ(11);
  1. @TagNumber.new(12)
set routeToken (String v)

Implementation

@$pb.TagNumber(12)
set routeToken($core.String v) {
  $_setString(11, v);
}