RouteLeg class

Contains a segment between non-via waypoints.

Inheritance
  • Object
  • GeneratedMessage
  • RouteLeg

Constructors

RouteLeg({int? distanceMeters, Duration? duration, Duration? staticDuration, Polyline? polyline, Location? startLocation, Location? endLocation, Iterable<RouteLegStep>? steps, RouteLegTravelAdvisory? travelAdvisory, RouteLeg_RouteLegLocalizedValues? localizedValues, RouteLeg_StepsOverview? stepsOverview})
factory
RouteLeg.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
RouteLeg.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

distanceMeters ↔ int
The travel distance of the route leg, in meters.
getter/setter pair
duration ↔ Duration
The length of time needed to navigate the leg. If the route_preference is set to TRAFFIC_UNAWARE, then this value is the same as static_duration. If the route_preference is either TRAFFIC_AWARE or TRAFFIC_AWARE_OPTIMAL, then this value is calculated taking traffic conditions into account.
getter/setter pair
endLocation ↔ Location
The end location of this leg. This location might be different from the provided destination. For example, when the provided destination is not near a road, this is a point on the road.
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
localizedValues ↔ RouteLeg_RouteLegLocalizedValues
Text representations of properties of the RouteLeg.
getter/setter pair
polyline ↔ Polyline
The overall polyline for this leg that includes each step's polyline.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLocation ↔ Location
The start location of this leg. This location might be different from the provided origin. For example, when the provided origin is not near a road, this is a point on the road.
getter/setter pair
staticDuration ↔ Duration
The duration of travel through the leg, calculated without taking traffic conditions into consideration.
getter/setter pair
steps → List<RouteLegStep>
An array of steps denoting segments within this leg. Each step represents one navigation instruction.
no setter
stepsOverview ↔ RouteLeg_StepsOverview
Overview information about the steps in this RouteLeg. This field is only populated for TRANSIT routes.
getter/setter pair
travelAdvisory ↔ RouteLegTravelAdvisory
Contains the additional information that the user should be informed about, such as possible traffic zone restrictions, on a route leg.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearDistanceMeters() → void
clearDuration() → void
clearEndLocation() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLocalizedValues() → void
clearPolyline() → void
clearStartLocation() → void
clearStaticDuration() → void
clearStepsOverview() → void
clearTravelAdvisory() → void
clone() → RouteLeg
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(RouteLeg)) → RouteLeg
Apply updates to a copy of this message.
override
createEmptyInstance() → RouteLeg
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureDuration() → Duration
ensureEndLocation() → Location
ensureLocalizedValues() → RouteLeg_RouteLegLocalizedValues
ensurePolyline() → Polyline
ensureStartLocation() → Location
ensureStaticDuration() → Duration
ensureStepsOverview() → RouteLeg_StepsOverview
ensureTravelAdvisory() → RouteLegTravelAdvisory
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasDistanceMeters() → bool
hasDuration() → bool
hasEndLocation() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasLocalizedValues() → bool
hasPolyline() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStartLocation() → bool
hasStaticDuration() → bool
hasStepsOverview() → bool
hasTravelAdvisory() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → RouteLeg
createRepeated() → PbList<RouteLeg>
getDefault() → RouteLeg