duration property

  1. @TagNumber.new(2)
Duration get duration

The length of time needed to navigate the leg. If the route_preference is set to TRAFFIC_UNAWARE, then this value is the same as static_duration. If the route_preference is either TRAFFIC_AWARE or TRAFFIC_AWARE_OPTIMAL, then this value is calculated taking traffic conditions into account.

Implementation

@$pb.TagNumber(2)
$10.Duration get duration => $_getN(1);
  1. @TagNumber.new(2)
set duration (Duration v)

Implementation

@$pb.TagNumber(2)
set duration($10.Duration v) {
  setField(2, v);
}