endLocation property

  1. @TagNumber.new(6)
Location get endLocation

The end location of this leg. This location might be different from the provided destination. For example, when the provided destination is not near a road, this is a point on the road.

Implementation

@$pb.TagNumber(6)
$9.Location get endLocation => $_getN(5);
  1. @TagNumber.new(6)
set endLocation (Location v)

Implementation

@$pb.TagNumber(6)
set endLocation($9.Location v) {
  setField(6, v);
}