staticDuration property
The duration of travel through this step without taking traffic conditions into consideration. In some circumstances, this field might not have a value.
Implementation
@$pb.TagNumber(2)
$10.Duration get staticDuration => $_getN(1);
Implementation
@$pb.TagNumber(2)
set staticDuration($10.Duration v) {
setField(2, v);
}