transitLine property
Information about the transit line used in this step.
Implementation
@$pb.TagNumber(5)
$17.TransitLine get transitLine => $_getN(4);
Implementation
@$pb.TagNumber(5)
set transitLine($17.TransitLine v) {
setField(5, v);
}
Information about the transit line used in this step.
@$pb.TagNumber(5)
$17.TransitLine get transitLine => $_getN(4);
@$pb.TagNumber(5)
set transitLine($17.TransitLine v) {
setField(5, v);
}