RouteMatrixElement class

Contains route information computed for an origin/destination pair in the ComputeRouteMatrix API. This proto can be streamed to the client.

Inheritance
  • Object
  • GeneratedMessage
  • RouteMatrixElement

Constructors

RouteMatrixElement({int? originIndex, int? destinationIndex, Status? status, int? distanceMeters, Duration? duration, Duration? staticDuration, RouteTravelAdvisory? travelAdvisory, FallbackInfo? fallbackInfo, RouteMatrixElementCondition? condition, RouteMatrixElement_LocalizedValues? localizedValues})
factory
RouteMatrixElement.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
RouteMatrixElement.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

condition ↔ RouteMatrixElementCondition
Indicates whether the route was found or not. Independent of status.
getter/setter pair
destinationIndex ↔ int
Zero-based index of the destination in the request.
getter/setter pair
distanceMeters ↔ int
The travel distance of the route, in meters.
getter/setter pair
duration ↔ Duration
The length of time needed to navigate the route. If you set the google.maps.routing.v2.ComputeRouteMatrixRequest.routing_preference to TRAFFIC_UNAWARE, then this value is the same as static_duration. If you set the routing_preference to either TRAFFIC_AWARE or TRAFFIC_AWARE_OPTIMAL, then this value is calculated taking traffic conditions into account.
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
fallbackInfo ↔ FallbackInfo
In some cases when the server is not able to compute the route with the given preferences for this particular origin/destination pair, it may fall back to using a different mode of computation. When fallback mode is used, this field contains detailed information about the fallback response. Otherwise this field is unset.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
localizedValues ↔ RouteMatrixElement_LocalizedValues
Text representations of properties of the RouteMatrixElement.
getter/setter pair
originIndex ↔ int
Zero-based index of the origin in the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticDuration ↔ Duration
The duration of traveling through the route without taking traffic conditions into consideration.
getter/setter pair
status ↔ Status
Error status code for this element.
getter/setter pair
travelAdvisory ↔ RouteTravelAdvisory
Additional information about the route. For example: restriction information and toll information
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCondition() → void
clearDestinationIndex() → void
clearDistanceMeters() → void
clearDuration() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFallbackInfo() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLocalizedValues() → void
clearOriginIndex() → void
clearStaticDuration() → void
clearStatus() → void
clearTravelAdvisory() → void
clone() → RouteMatrixElement
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(RouteMatrixElement)) → RouteMatrixElement
Apply updates to a copy of this message.
override
createEmptyInstance() → RouteMatrixElement
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureDuration() → Duration
ensureFallbackInfo() → FallbackInfo
ensureLocalizedValues() → RouteMatrixElement_LocalizedValues
ensureStaticDuration() → Duration
ensureStatus() → Status
ensureTravelAdvisory() → RouteTravelAdvisory
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCondition() → bool
hasDestinationIndex() → bool
hasDistanceMeters() → bool
hasDuration() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasFallbackInfo() → bool
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasLocalizedValues() → bool
hasOriginIndex() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasStaticDuration() → bool
hasStatus() → bool
hasTravelAdvisory() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited