avoidIndoor property

  1. @TagNumber.new(4)
bool get avoidIndoor

When set to true, avoids navigating indoors where reasonable, giving preference to routes not containing indoor navigation. Applies only to the WALK google.maps.routing.v2.RouteTravelMode.

Implementation

@$pb.TagNumber(4)
$core.bool get avoidIndoor => $_getBF(3);
  1. @TagNumber.new(4)
set avoidIndoor (bool v)

Implementation

@$pb.TagNumber(4)
set avoidIndoor($core.bool v) {
  $_setBool(3, v);
}