avoidTolls property

  1. @TagNumber.new(1)
bool get avoidTolls

When set to true, avoids toll roads where reasonable, giving preference to routes not containing toll roads. Applies only to the DRIVE and TWO_WHEELER google.maps.routing.v2.RouteTravelMode.

Implementation

@$pb.TagNumber(1)
$core.bool get avoidTolls => $_getBF(0);
  1. @TagNumber.new(1)
set avoidTolls (bool v)

Implementation

@$pb.TagNumber(1)
set avoidTolls($core.bool v) {
  $_setBool(0, v);
}