RoutesServiceBase class abstract

Annotations
  • @GrpcServiceName.new('google.maps.routing.v2.Routes')

Constructors

RoutesServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
computeRouteMatrix(ServiceCall call, ComputeRouteMatrixRequest request) → Stream<RouteMatrixElement>
computeRouteMatrix_Pre(ServiceCall call, Future<ComputeRouteMatrixRequest> request) → Stream<RouteMatrixElement>
computeRoutes(ServiceCall call, ComputeRoutesRequest request) → Future<ComputeRoutesResponse>
computeRoutes_Pre(ServiceCall call, Future<ComputeRoutesRequest> request) → Future<ComputeRoutesResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited