estimatedPrice property

  1. @TagNumber.new(1)
List<Money> get estimatedPrice

The monetary amount of tolls for the corresponding google.maps.routing.v2.Route or google.maps.routing.v2.RouteLeg. This list contains a money amount for each currency that is expected to be charged by the toll stations. Typically this list will contain only one item for routes with tolls in one currency. For international trips, this list may contain multiple items to reflect tolls in different currencies.

Implementation

@$pb.TagNumber(1)
$core.List<$8.Money> get estimatedPrice => $_getList(0);