copyWith method

  1. @Deprecated('Using this can add significant overhead to your binary. ' 'Use [GeneratedMessageGenericExtensions.rebuild] instead. ' 'Will be removed in next major version')
FieldOptions_EditionDefault copyWith(
  1. void updates(
    1. FieldOptions_EditionDefault
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('Using this can add significant overhead to your binary. '
    'Use [GeneratedMessageGenericExtensions.rebuild] instead. '
    'Will be removed in next major version')
FieldOptions_EditionDefault copyWith(
        void Function(FieldOptions_EditionDefault) updates) =>
    super.copyWith(
            (message) => updates(message as FieldOptions_EditionDefault))
        as FieldOptions_EditionDefault;