deprecationWarning property
The deprecation warning text if this feature is used after the edition it was marked deprecated in.
Implementation
@$pb.TagNumber(3)
$core.String get deprecationWarning => $_getSZ(2);
Implementation
@$pb.TagNumber(3)
set deprecationWarning($core.String v) {
$_setString(2, v);
}