legacyClosedEnum property
Whether or not to treat an enum field as closed. This option is only applicable to enum fields, and will be removed in the future. It is consistent with the legacy behavior of using proto3 enum types for proto2 fields.
Implementation
@$pb.TagNumber(1)
$core.bool get legacyClosedEnum => $_getBF(0);
Implementation
@$pb.TagNumber(1)
set legacyClosedEnum($core.bool v) {
$_setBool(0, v);
}