edition property
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Implementation
@$pb.TagNumber(7)
$core.String get edition => $_getSZ(6);
Implementation
@$pb.TagNumber(7)
set edition($core.String v) {
$_setString(6, v);
}
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
@$pb.TagNumber(7)
$core.String get edition => $_getSZ(6);
@$pb.TagNumber(7)
set edition($core.String v) {
$_setString(6, v);
}