field_1 property

  1. @TagNumber.new(1)
String get field_1

A path that leads to a field in the request body. The value will be a sequence of dot-separated identifiers that identify a protocol buffer field.

Consider the following:

 message CreateContactRequest {
   message EmailAddress {
     enum Type {
       TYPE_UNSPECIFIED = 0;
       HOME = 1;
       WORK = 2;
     }

     optional string email = 1;
     repeated EmailType type = 2;
   }

   string full_name = 1;
   repeated EmailAddress email_addresses = 2;
 }

In this example, in proto field could take one of the following values:

  • full_name for a violation in the full_name value
  • email_addresses[1].email for a violation in the email field of the first email_addresses message
  • email_addresses[3].type[2] for a violation in the second type value in the third email_addresses message.

In JSON, the same values are represented as:

  • fullName for a violation in the fullName value
  • emailAddresses[1].email for a violation in the email field of the first emailAddresses message
  • emailAddresses[3].type[2] for a violation in the second type value in the third emailAddresses message.

Implementation

@$pb.TagNumber(1)
$core.String get field_1 => $_getSZ(0);
  1. @TagNumber.new(1)
set field_1 (String v)

Implementation

@$pb.TagNumber(1)
set field_1($core.String v) {
  $_setString(0, v);
}