annotations property

  1. @TagNumber.new(6)
Map<String, String> get annotations

Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations/

Implementation

@$pb.TagNumber(6)
$core.Map<$core.String, $core.String> get annotations => $_getMap(5);