updateTime property
Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.
Implementation
@$pb.TagNumber(9)
$18.Timestamp get updateTime => $_getN(8);
Implementation
@$pb.TagNumber(9)
set updateTime($18.Timestamp v) {
setField(9, v);
}