time property
The timestamp when the destination service sends the last byte of
the response.
Implementation
@$pb.TagNumber(4)
$18.Timestamp get time => $_getN(3);
Implementation
@$pb.TagNumber(4)
set time($18.Timestamp v) {
setField(4, v);
}
The timestamp when the destination service sends the last byte of
the response.
@$pb.TagNumber(4)
$18.Timestamp get time => $_getN(3);
@$pb.TagNumber(4)
set time($18.Timestamp v) {
setField(4, v);
}