scrubbedRequest property

  1. @TagNumber.new(2)
Struct get scrubbedRequest

An API request message that is scrubbed based on the method annotation. This field should only be filled if audit_log field is present. Service Control will use this to assemble a complete log for Cloud Audit Logs and Google internal audit logs.

Implementation

@$pb.TagNumber(2)
$7.Struct get scrubbedRequest => $_getN(1);
  1. @TagNumber.new(2)
set scrubbedRequest (Struct v)

Implementation

@$pb.TagNumber(2)
set scrubbedRequest($7.Struct v) {
  setField(2, v);
}