day property
Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.
Implementation
@$pb.TagNumber(3)
$core.int get day => $_getIZ(2);
Implementation
@$pb.TagNumber(3)
set day($core.int v) {
$_setSignedInt32(2, v);
}