DayOfWeek class

Represents a day of the week.

Inheritance
  • Object
  • ProtobufEnum
  • DayOfWeek

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → DayOfWeek?

Constants

DAY_OF_WEEK_UNSPECIFIED → const DayOfWeek
FRIDAY → const DayOfWeek
MONDAY → const DayOfWeek
SATURDAY → const DayOfWeek
SUNDAY → const DayOfWeek
THURSDAY → const DayOfWeek
TUESDAY → const DayOfWeek
values → const List<DayOfWeek>
WEDNESDAY → const DayOfWeek