startTime property
Optional. Inclusive start of the interval.
If specified, a Timestamp matching this interval will have to be the same or after the start.
Implementation
@$pb.TagNumber(1)
$18.Timestamp get startTime => $_getN(0);
Implementation
@$pb.TagNumber(1)
set startTime($18.Timestamp v) {
setField(1, v);
}