Month class

Represents a month in the Gregorian calendar.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Month?

Constants

APRIL → const Month
AUGUST → const Month
DECEMBER → const Month
FEBRUARY → const Month
JANUARY → const Month
JULY → const Month
JUNE → const Month
MARCH → const Month
MAY → const Month
MONTH_UNSPECIFIED → const Month
NOVEMBER → const Month
OCTOBER → const Month
SEPTEMBER → const Month
values → const List<Month>