e164Number property

  1. @TagNumber.new(1)
String get e164Number

The phone number, represented as a leading plus sign ('+'), followed by a phone number that uses a relaxed ITU E.164 format consisting of the country calling code (1 to 3 digits) and the subscriber number, with no additional spaces or formatting, e.g.:

  • correct: "+15552220123"
  • incorrect: "+1 (555) 222-01234 x123".

The ITU E.164 format limits the latter to 12 digits, but in practice not all countries respect that, so we relax that restriction here. National-only numbers are not allowed.

References:

Implementation

@$pb.TagNumber(1)
$core.String get e164Number => $_getSZ(0);
  1. @TagNumber.new(1)
set e164Number (String v)

Implementation

@$pb.TagNumber(1)
set e164Number($core.String v) {
  $_setString(0, v);
}