extraComputations property
Optional. A list of extra computations which may be used to complete the request. Note: These extra computations may return extra fields on the response. These extra fields must also be specified in the field mask to be returned in the response.
Implementation
@$pb.TagNumber(8)
$core.List<ComputeRouteMatrixRequest_ExtraComputation>
get extraComputations => $_getList(7);