origins property
Required. Array of origins, which determines the rows of the response matrix. Several size restrictions apply to the cardinality of origins and destinations:
- The sum of the number of origins + the number of destinations specified
as either
place_idoraddressmust be no greater than 50. - The product of number of origins × number of destinations must be no greater than 625 in any case.
- The product of the number of origins × number of destinations must be no
greater than 100 if routing_preference is set to
TRAFFIC_AWARE_OPTIMAL. - The product of the number of origins × number of destinations must be no
greater than 100 if travel_mode is set to
TRANSIT.
Implementation
@$pb.TagNumber(1)
$core.List<RouteMatrixOrigin> get origins => $_getList(0);