requestedReferenceRoutes property
Optional. Specifies what reference routes to calculate as part of the
request in addition to the default route. A reference route is a route with
a different route calculation objective than the default route. For example
a FUEL_EFFICIENT reference route calculation takes into account various
parameters that would generate an optimal fuel efficient route. When using
this feature, look for
google.maps.routing.v2.Route.route_labels on the
resulting routes.
Implementation
@$pb.TagNumber(14)
$core.List<ComputeRoutesRequest_ReferenceRoute>
get requestedReferenceRoutes => $_getList(13);