trafficModel property
Optional. Specifies the assumptions to use when calculating time in
traffic. This setting affects the value returned in the duration field in
the
google.maps.routing.v2.Route and
google.maps.routing.v2.RouteLeg which contains the predicted
time in traffic based on historical averages.
TrafficModel is only available for requests that have set
google.maps.routing.v2.RoutingPreference to
TRAFFIC_AWARE_OPTIMAL and
google.maps.routing.v2.RouteTravelMode to DRIVE.
Defaults to BEST_GUESS if traffic is requested and TrafficModel is not
specified.
Implementation
@$pb.TagNumber(18)
$33.TrafficModel get trafficModel => $_getN(16);
Implementation
@$pb.TagNumber(18)
set trafficModel($33.TrafficModel v) {
setField(18, v);
}