intermediateWaypointRequestIndex property
The index of the corresponding intermediate waypoint in the request. Only populated if the corresponding waypoint is an intermediate waypoint.
Implementation
@$pb.TagNumber(2)
$core.int get intermediateWaypointRequestIndex => $_getIZ(1);
Implementation
@$pb.TagNumber(2)
set intermediateWaypointRequestIndex($core.int v) {
$_setSignedInt32(1, v);
}