intermediates property
A list of intermediate geocoded waypoints each containing an index field that corresponds to the zero-based position of the waypoint in the order they were specified in the request.
Implementation
@$pb.TagNumber(3)
$core.List<GeocodedWaypoint> get intermediates => $_getList(2);