heading property
The compass heading associated with the direction of the flow of traffic.
This value specifies the side of the road for pickup and drop-off. Heading
values can be from 0 to 360, where 0 specifies a heading of due North, 90
specifies a heading of due East, and so on. You can use this field only for
DRIVE and TWO_WHEELER
google.maps.routing.v2.RouteTravelMode.
Implementation
@$pb.TagNumber(2)
$5.Int32Value get heading => $_getN(1);
Implementation
@$pb.TagNumber(2)
set heading($5.Int32Value v) {
setField(2, v);
}