optimizedIntermediateWaypointIndex property
If you set
google.maps.routing.v2.ComputeRoutesRequest.optimize_waypoint_order
to true, this field contains the optimized ordering of intermediate
waypoints. Otherwise, this field is empty.
For example, if you give an input of Origin: LA; Intermediate waypoints:
Dallas, Bangor, Phoenix; Destination: New York; and the optimized
intermediate waypoint order is Phoenix, Dallas, Bangor, then this field
contains the values 2, 0, 1. The index starts with 0 for the first
intermediate waypoint provided in the input.
Implementation
@$pb.TagNumber(10)
$core.List<$core.int> get optimizedIntermediateWaypointIndex => $_getList(9);