stopCount property
The number of stops from the departure to the arrival stop. This count
includes the arrival stop, but excludes the departure stop. For example, if
your route leaves from Stop A, passes through stops B and C, and arrives at
stop D, stop_count returns 3.
Implementation
@$pb.TagNumber(6)
$core.int get stopCount => $_getIZ(5);
Implementation
@$pb.TagNumber(6)
set stopCount($core.int v) {
$_setSignedInt32(5, v);
}