tripShortText property
The text that appears in schedules and sign boards to identify a transit
trip to passengers. The text should uniquely identify a trip within a
service day. For example, "538" is the trip_short_text of the Amtrak
train that leaves San Jose, CA at 15:10 on weekdays to Sacramento, CA.
Implementation
@$pb.TagNumber(7)
$core.String get tripShortText => $_getSZ(6);
Implementation
@$pb.TagNumber(7)
set tripShortText($core.String v) {
$_setString(6, v);
}