fallbackInfo property
In some cases when the server is not able to compute the route with the given preferences for this particular origin/destination pair, it may fall back to using a different mode of computation. When fallback mode is used, this field contains detailed information about the fallback response. Otherwise this field is unset.
Implementation
@$pb.TagNumber(8)
$29.FallbackInfo get fallbackInfo => $_getN(7);
Implementation
@$pb.TagNumber(8)
set fallbackInfo($29.FallbackInfo v) {
setField(8, v);
}