duration property
Duration, represented in text form and localized to the region of the
query. Takes traffic conditions into consideration. Note: If you did not
request traffic information, this value is the same value as
static_duration.
Implementation
@$pb.TagNumber(2)
$3.LocalizedText get duration => $_getN(1);
Implementation
@$pb.TagNumber(2)
set duration($3.LocalizedText v) {
setField(2, v);
}